@@ -72,13 +72,15 @@ def qsphere(state, state_labels=True,
         if not abs(1-state.data.dot(state.data).trace().real) < 1e-6:
             raise KaleidoscopeError('Input density matrix is not a pure state.')
         # pylint: disable=unexpected-keyword-arg
-        state = la.eigh(state.data, subset_by_value=[0.99, 1.01])[1].ravel()
+        _, evecs = la.eig(state.data)
+        state = evecs[0].ravel()
 
     if len(state.shape) == 2:
         if not abs(1-state.dot(state).trace().real) < 1e-6:
             raise KaleidoscopeError('Input density matrix is not a pure state.')
         # pylint: disable=unexpected-keyword-arg
-        state = la.eigh(state, subset_by_value=[0.99, 1.01])[1].ravel()
+        _, evecs = la.eig(state.data)
+        state = evecs[0].ravel()
 
     if len(state.shape) != 1:
         raise KaleidoscopeError('Input state is not 1D array.')
