@@ -23,4 +23,5 @@ if not HAS_QISKIT:
 
 import kaleidoscope.qiskit.overload
 from .backends.mpl import *
-from .backends.interactive import system_error_map
+from .backends.interactive import system_error_map, system_gate_map
+from .services import Account, Systems, Simulators
